@@ -14,8 +14,8 @@
 
 
 import copy
+from unittest import mock
 
-import mock
 from neutronclient.common import exceptions as neutron_exception
 
 from ec2api.tests.unit import base
